pub enum QueryCommands {
ConnectedFiles {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
file_pos: Option<String>,
file: Option<String>,
graph: Option<String>,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
ItemInfo {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
item_id: Option<String>,
name: Option<String>,
kind: Option<ItemKindArg>,
graph: Option<String>,
show_code: bool,
format: OutputFormat,
},
FunctionUsage {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
function: String,
direction: Direction,
graph: Option<String>,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
Cycles {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
graph: Option<String>,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
Path {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
from: String,
to: String,
graph: Option<String>,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
Hubs {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
graph: Option<String>,
metric: CentralityMetricArg,
top: usize,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
ModuleCentrality {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
graph: Option<String>,
metric: CentralityMetricArg,
top: usize,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
TraitImpls {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
trait: String,
graph: Option<String>,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
UnreferencedItems {
path: Option<PathBuf>,
config: Option<String>,
no_ignore: bool,
include_public: bool,
exclude: Option<String>,
graph: Option<String>,
format: OutputFormat,
offset: usize,
limit: Option<usize>,
},
}Variants
ConnectedFiles
List files connected to the given file via relationships
Fields
format: OutputFormatOutput format: text or json
ItemInfo
Show a single item’s definition and relations by ItemId
Fields
name: Option<String>Lookup by item name (e.g., createIcons). Use with optional –kind to disambiguate
kind: Option<ItemKindArg>Optional kind to narrow name lookup (e.g., function, struct)
format: OutputFormatOutput format: text or json
FunctionUsage
List files that call or are called by a given function name
Fields
format: OutputFormatOutput format: text or json
Cycles
Detect cycles between files
Fields
format: OutputFormatOutput format: text or json
Path
Compute shortest path between two files
Fields
format: OutputFormatOutput format: text or json
Hubs
List top-N hub files by degree centrality
Fields
metric: CentralityMetricArgMetric: in, out, total
format: OutputFormatOutput format: text or json
ModuleCentrality
List top-N modules (directories) by degree centrality
Fields
metric: CentralityMetricArgMetric: in, out, total
format: OutputFormatOutput format: text or json
TraitImpls
List types implementing a trait
Fields
format: OutputFormatOutput format: text or json
UnreferencedItems
List items with no inbound usage edges (potentially dead code)
Fields
format: OutputFormatOutput format: text or json