pub struct Resolver<'a> { /* private fields */ }Implementations
Sourceimpl<'a> Resolver<'a>
impl<'a> Resolver<'a>
Sourcepub fn find_by_name(&self, name: &str) -> Vec<ItemId>
pub fn find_by_name(&self, name: &str) -> Vec<ItemId>
Find items by simple name using the prebuilt name index.
Sourcepub fn item_path(&self, id: &ItemId) -> Option<&PathBuf>
pub fn item_path(&self, id: &ItemId) -> Option<&PathBuf>
Get the file path where an item is defined.
Sourcepub fn item_kind(&self, id: &ItemId) -> Option<ItemType>
pub fn item_kind(&self, id: &ItemId) -> Option<ItemType>
Get the ItemType (kind) for a given item id.
pub fn new(graph: &'a KnowledgeGraph) -> Self
pub fn resolve_import(&self, from_file: &Path, raw_path: &str) -> Vec<ItemId>
pub fn is_item_function(&self, id: &ItemId) -> bool
pub fn is_file_level_module(&self, id: &ItemId) -> bool