pub struct RustParser { /* private fields */ }Implementations
Sourceimpl RustParser
impl RustParser
pub fn new() -> Self
Sourcepub fn parse_file(
&self,
content: &str,
path: &Path,
) -> Result<FileNode, ParseError>
pub fn parse_file( &self, content: &str, path: &Path, ) -> Result<FileNode, ParseError>
Parse a Rust source file contents into a FileNode with items and imports.
Errors
Returns ParseError when the input cannot be parsed due to invalid UTF-8 or other parser failures.