pub struct ConnectedFilesQuery {
pub file: PathBuf,
}Expand description
Return the set of files directly connected to a target file by any relationship involving items defined in that file (edge endpoints at item-level are projected to file-level).
Fields
file: PathBufImplementations