Module file_walker

Functions

rust_files
Backward-compatible helper that reads env var and delegates to rust_files_with_options.
rust_files_with_options
Discover Rust source files under root, with an option to bypass ignore rules.