Enum QueryCommands

pub enum QueryCommands {
    ConnectedFiles {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        file: String,
        graph: Option<String>,
        format: String,
    },
    ItemInfo {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        item_id: String,
        graph: Option<String>,
        show_code: bool,
        format: String,
    },
    FunctionUsage {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        function: String,
        direction: String,
        graph: Option<String>,
        format: String,
    },
    Cycles {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        graph: Option<String>,
        format: String,
    },
    Path {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        from: String,
        to: String,
        graph: Option<String>,
        format: String,
    },
    Hubs {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        graph: Option<String>,
        metric: String,
        top: usize,
        format: String,
    },
    ModuleCentrality {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        graph: Option<String>,
        metric: String,
        top: usize,
        format: String,
    },
    TraitImpls {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        trait: String,
        graph: Option<String>,
        format: String,
    },
    UnreferencedItems {
        path: String,
        config: Option<String>,
        no_ignore: bool,
        include_public: bool,
        exclude: Option<String>,
        graph: Option<String>,
        format: String,
    },
}

Variants



ConnectedFiles

List files connected to the given file via relationships

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

file: String

The file to analyze (absolute or relative)

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

format: String

Output format: text or json



ItemInfo

Show a single item’s definition and relations by ItemId

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

item_id: String

ItemId (e.g., fn:createIcons:6)

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

show_code: bool

Include code snippet of the item’s definition

format: String

Output format: text or json



FunctionUsage

List files that call or are called by a given function name

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

function: String

Function name to analyze

direction: String

Direction: callers or callees

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

format: String

Output format: text or json



Cycles

Detect cycles between files

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

format: String

Output format: text or json



Path

Compute shortest path between two files

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

from: String

Source file path

to: String

Destination file path

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

format: String

Output format: text or json



Hubs

List top-N hub files by degree centrality

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

metric: String

Metric: in, out, total

top: usize

Top N results

format: String

Output format: text or json



ModuleCentrality

List top-N modules (directories) by degree centrality

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

metric: String

Metric: in, out, total

top: usize

Top N results

format: String

Output format: text or json



TraitImpls

List types implementing a trait

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

trait: String

Trait name (e.g., Display)

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

format: String

Output format: text or json



UnreferencedItems

List items with no inbound usage edges (potentially dead code)

Fields

path: String

Path to project root (directory containing src/)

config: Option<String>

Path to a TOML configuration file

no_ignore: bool

Bypass ignore rules (.gitignore/.ignore) when discovering files

include_public: bool

Include public items as well (by default public items are excluded)

exclude: Option<String>

Regex to exclude paths (e.g., ‘tests|benches|examples’)

graph: Option<String>

Optional path to a prebuilt graph JSON (skips rebuild)

format: String

Output format: text or json