pub enum QueryCommands {
ConnectedFiles {
path: String,
config: Option<String>,
no_ignore: bool,
file: String,
graph: Option<String>,
format: String,
},
ItemInfo {
path: String,
config: Option<String>,
no_ignore: bool,
item_id: String,
graph: Option<String>,
show_code: bool,
format: String,
},
FunctionUsage {
path: String,
config: Option<String>,
no_ignore: bool,
function: String,
direction: String,
graph: Option<String>,
format: String,
},
Cycles {
path: String,
config: Option<String>,
no_ignore: bool,
graph: Option<String>,
format: String,
},
Path {
path: String,
config: Option<String>,
no_ignore: bool,
from: String,
to: String,
graph: Option<String>,
format: String,
},
Hubs {
path: String,
config: Option<String>,
no_ignore: bool,
graph: Option<String>,
metric: String,
top: usize,
format: String,
},
ModuleCentrality {
path: String,
config: Option<String>,
no_ignore: bool,
graph: Option<String>,
metric: String,
top: usize,
format: String,
},
TraitImpls {
path: String,
config: Option<String>,
no_ignore: bool,
trait: String,
graph: Option<String>,
format: String,
},
UnreferencedItems {
path: String,
config: Option<String>,
no_ignore: bool,
include_public: bool,
exclude: Option<String>,
graph: Option<String>,
format: String,
},
}Variants
ConnectedFiles
List files connected to the given file via relationships
Fields
ItemInfo
Show a single item’s definition and relations by ItemId
Fields
FunctionUsage
List files that call or are called by a given function name
Fields
Cycles
Detect cycles between files
Fields
Path
Compute shortest path between two files
Fields
Hubs
List top-N hub files by degree centrality
Fields
ModuleCentrality
List top-N modules (directories) by degree centrality
Fields
TraitImpls
List types implementing a trait
Fields
UnreferencedItems
List items with no inbound usage edges (potentially dead code)
Fields