Functions
- detect
- Detect the Cargo project root by walking ancestors looking for both
Cargo.tomlandsrc/. - effective_
path_ opt - Convert an optional Path into an effective absolute project root path. None or “.” resolve to the detected project root; any other path is returned as owned PathBuf.
- effective_
path_ str - If
pis “.” (implicit default), replace with detected project root. Otherwise, return as-is.